@@ -2,9 +2,9 @@ package Catalyst::Plugin::RapidApp::NavCore::GridRole;
 use strict;
 use warnings;
 use Moose::Role;
-with 'RapidApp::Role::DataStore2::SavedSearch';
+with 'RapidApp::Module::StorCmp::Role::SavedSearch';
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 # This Role must be loaded in Grids for "Save Search" to be available in the
 # options menu. Even if loaded, this Role will not enable itself unless the
