@@ -967,8 +967,6 @@ sub controller_dispatch {
   
   my $ct= $self->c->stash->{requestContentType};
   
-  $self->_maybe_special_path_redirect($opt,@subargs) if ($opt);
-  
   # if there were unprocessed arguments which were not an action, and there was no default action, generate a 404
   # UPDATE: unless new 'accept_subargs' attr is true (see attribute declaration above)
   if (defined $opt && !$self->accept_subargs) {
@@ -1020,22 +1018,6 @@ sub controller_dispatch {
 }
 
 
-# TODO: deprecate/remove in favor of better _ra-rel-mnt_ solution - GitHub Issue #153
-sub _maybe_special_path_redirect {
-  my ($self, $opt, @subargs)= @_;
-  my $c = $self->c;
-  
-  # Special handling for relative requests to special/reserved controller paths.
-  # This allows us to use relative paths in front-side code and for it to just
-  # work, even if we change our mount path later on
-  $c->redispatch_public_path($c->mount_url,$opt,@subargs) && $c->detach if (
-       $opt eq 'simplecas'
-    || $opt eq 'assets'
-    #|| $opt eq 'rapidapp'   #<-- we don't need this that much
-  );
-}
-
-
 # This call happens via local method so subclasses are able to override
 sub auto_hashnav_redirect_current {
   my $self = shift;
